Crate spragga

Crate spragga 

SprayList: A Scalable Relaxed Priority Queue

This crate provides an implementation of the SprayList data structure, a scalable concurrent priority queue with relaxed ordering semantics.

Re-exports

pub use spraylist::SprayList;
pub use spraylist::SprayParams;

Modules

rng
skiplist
Lock-free skiplist implementation using std library atomics Based on Fraser’s algorithm with pointer marking for node deletion
spraylist
A scalable relaxed priority queue implementation.